@@ -1,4 +1,4 @@
-// -*- c-mode -*-
+// -*- c -*-
 
 var __cache = {};
 
@@ -27,6 +27,12 @@ function __cacheGet(id) {
   return comp;
 }
 
+function replace(page, ignored, immediate) {
+  // TODO: Better implementation
+  pop();
+  push(page, ignored, immediate);
+}
+
 function push(page, ignored, immediate) {
   // TODO: kill point
 
